==> gcl-1.0.tgz: gcl-1.0/lsp/numlib.h <==

static L15();
static L16();
static L17();
static L18();
static object LI1();
#define VMB1 register object *base=vs_top;
#define VMS1  register object *sup=vs_top+4;vs_top=sup;
#define VMV1 vs_reserve(4);
#define VMR1(VMT1) vs_top=base ; return(VMT1);
static object LI2();
#define VMB2 register object *base=vs_top; object  V15 ,V14 ,V13 ,V12 ,V11 ,V10;
#define VMS2  register object *sup=vs_top+2;vs_top=sup;
#define VMV2 vs_reserve(2);
#define VMR2(VMT2) vs_top=base ; return(VMT2);
static object LI3();
#define VMB3 register object *base=vs_top;
#define VMS3  register object *sup=vs_top+3;vs_top=sup;
#define VMV3 vs_reserve(3);
#define VMR3(VMT3) vs_top=base ; return(VMT3);
static object LI4();
#define VMB4 register object *base=vs_top;
#define VMS4  register object *sup=vs_top+2;vs_top=sup;
#define VMV4 vs_reserve(2);
#define VMR4(VMT4) vs_top=base ; return(VMT4);
static object LI5();
#define VMB5 register object *base=vs_top;
#define VMS5  register object *sup=vs_top+1;vs_top=sup;
#define VMV5 vs_reserve(1);
#define VMR5(VMT5) vs_top=base ; return(VMT5);
static object LI6();
#define VMB6 register object *base=vs_top; object  V37 ,V36 ,V35 ,V34 ,V33 ,V32;
#define VMS6  register object *sup=vs_top+2;vs_top=sup;
#define VMV6 vs_reserve(2);
#define VMR6(VMT6) vs_top=base ; return(VMT6);
static object LI7();
#define VMB7 register object *base=vs_top; object  V48 ,V47 ,V46 ,V45 ,V44 ,V43;
#define VMS7  register object *sup=vs_top+2;vs_top=sup;
#define VMV7 vs_reserve(2);
#define VMR7(VMT7) vs_top=base ; return(VMT7);
static object LI8();
#define VMB8 register object *base=vs_top; object  V54 ,V53;
#define VMS8  register object *sup=vs_top+2;vs_top=sup;
#define VMV8 vs_reserve(2);
#define VMR8(VMT8) vs_top=base ; return(VMT8);
static object LI9();
#define VMB9 register object *base=vs_top; object  V59 ,V58;
#define VMS9  register object *sup=vs_top+2;vs_top=sup;
#define VMV9 vs_reserve(2);
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static object LI10();
#define VMB10 register object *base=vs_top;
#define VMS10  register object *sup=vs_top+2;vs_top=sup;
#define VMV10 vs_reserve(2);
#define VMR10(VMT10) vs_top=base ; return(VMT10);
static object LI11();
#define VMB11 register object *base=vs_top; object  V67 ,V66;
#define VMS11  register object *sup=vs_top+2;vs_top=sup;
#define VMV11 vs_reserve(2);
#define VMR11(VMT11) vs_top=base ; return(VMT11);
static object LI12();
#define VMB12 register object *base=vs_top; object  V73 ,V72 ,V71;
#define VMS12  register object *sup=vs_top+4;vs_top=sup;
#define VMV12 vs_reserve(4);
#define VMR12(VMT12) vs_top=base ; return(VMT12);
static object LI13();
#define VMB13 register object *base=vs_top; object  V77;
#define VMS13  register object *sup=vs_top+4;vs_top=sup;
#define VMV13 vs_reserve(4);
#define VMR13(VMT13) vs_top=base ; return(VMT13);
static object LI14();
#define VMB14 register object *base=vs_top; object  V90 ,V89 ,V88 ,V86 ,V85;
#define VMS14  register object *sup=vs_top+1;vs_top=sup;
#define VMV14 vs_reserve(1);
#define VMR14(VMT14) vs_top=base ; return(VMT14);
#define VC15
#define VC16
#define VC17
#define VC18
static object LI19();
#define VMB19 register object *base=vs_top;
#define VMS19  register object *sup=vs_top+3;vs_top=sup;
#define VMV19 vs_reserve(3);
#define VMR19(VMT19) vs_top=base ; return(VMT19);
static object LI20();
#define VMB20 register object *base=vs_top;
#define VMS20  register object *sup=vs_top+3;vs_top=sup;
#define VMV20 vs_reserve(3);
#define VMR20(VMT20) vs_top=base ; return(VMT20);
static object LI21();
#define VMB21 register object *base=vs_top;
#define VMS21  register object *sup=vs_top+3;vs_top=sup;
#define VMV21 vs_reserve(3);
#define VMR21(VMT21) vs_top=base ; return(VMT21);
static object LI22();
#define VMB22 register object *base=vs_top;
#define VMS22  register object *sup=vs_top+3;vs_top=sup;
#define VMV22 vs_reserve(3);
#define VMR22(VMT22) vs_top=base ; return(VMT22);
static object LI23();
#define VMB23 register object *base=vs_top;
#define VMS23  register object *sup=vs_top+3;vs_top=sup;
#define VMV23 vs_reserve(3);
#define VMR23(VMT23) vs_top=base ; return(VMT23);
static object LI24();
#define VMB24 register object *base=vs_top;
#define VMS24  register object *sup=vs_top+3;vs_top=sup;
#define VMV24 vs_reserve(3);
#define VMR24(VMT24) vs_top=base ; return(VMT24);
static object LI25();
#define VMB25 register object *base=vs_top;
#define VMS25  register object *sup=vs_top+2;vs_top=sup;
#define VMV25 vs_reserve(2);
#define VMR25(VMT25) vs_top=base ; return(VMT25);
static object LI26();
#define VMB26 register object *base=vs_top; object  V147;
#define VMS26  register object *sup=vs_top+2;vs_top=sup;
#define VMV26 vs_reserve(2);
#define VMR26(VMT26) vs_top=base ; return(VMT26);
static object LI27();
#define VMB27
#define VMS27
#define VMV27
#define VMR27(VMT27) return(VMT27);
static object LI28();
#define VMB28
#define VMS28
#define VMV28
#define VMR28(VMT28) return(VMT28);
static object LI29();
#define VMB29
#define VMS29
#define VMV29
#define VMR29(VMT29) return(VMT29);
static object LI30();
#define VMB30 register object *base=vs_top; object  V167 ,V166 ,V165 ,V164;
#define VMS30  register object *sup=vs_top+2;vs_top=sup;
#define VMV30 vs_reserve(2);
#define VMR30(VMT30) vs_top=base ; return(VMT30);
static object LI31();
#define VMB31 object  V173;
#define VMS31
#define VMV31
#define VMR31(VMT31) return(VMT31);
static object LI32();
#define VMB32 register object *base=vs_top;
#define VMS32  register object *sup=vs_top+2;vs_top=sup;
#define VMV32 vs_reserve(2);
#define VMR32(VMT32) vs_top=base ; return(VMT32);
static object LI33();
#define VMB33 register object *base=vs_top; object  V187 ,V186;
#define VMS33  register object *sup=vs_top+6;vs_top=sup;
#define VMV33 vs_reserve(6);
#define VMR33(VMT33) vs_top=base ; return(VMT33);
static object LI34();
#define VMB34 register object *base=vs_top; object  V196 ,V195;
#define VMS34  register object *sup=vs_top+2;vs_top=sup;
#define VMV34 vs_reserve(2);
#define VMR34(VMT34) vs_top=base ; return(VMT34);
#define VM34 2
#define VM33 6
#define VM32 2
#define VM31 0
#define VM30 2
#define VM29 0
#define VM28 0
#define VM27 0
#define VM26 2
#define VM25 2
#define VM24 3
#define VM23 3
#define VM22 3
#define VM21 3
#define VM20 3
#define VM19 3
#define VM18 5
#define VM17 5
#define VM16 5
#define VM15 5
#define VM14 1
#define VM13 4
#define VM12 4
#define VM11 2
#define VM10 2
#define VM9 2
#define VM8 2
#define VM7 2
#define VM6 2
#define VM5 1
#define VM4 2
#define VM3 3
#define VM2 2
#define VM1 4
static char * VVi[34]={
#define Cdata VV[33]
(char *)(LI1),
(char *)(LI2),
(char *)(LI3),
(char *)(LI4),
(char *)(LI5),
(char *)(LI6),
(char *)(LI7),
(char *)(LI8),
(char *)(LI9),
(char *)(LI10),
(char *)(LI11),
(char *)(LI12),
(char *)(LI13),
(char *)(LI14),
(char *)(L15),
(char *)(L16),
(char *)(L17),
(char *)(L18),
(char *)(LI19),
(char *)(LI20),
(char *)(LI21),
(char *)(LI22),
(char *)(LI23),
(char *)(LI24),
(char *)(LI25),
(char *)(LI26),
(char *)(LI27),
(char *)(LI28),
(char *)(LI29),
(char *)(LI30),
(char *)(LI31),
(char *)(LI32),
(char *)(LI33),
(char *)(LI34)
};
#define VV ((object *)VVi)
static object  LnkTLI19() ;
static object  (*LnkLI19)() = LnkTLI19;
static object  LnkTLI18() ;
static object  (*LnkLI18)() = LnkTLI18;
static object  LnkTLI17() ;
static object  (*LnkLI17)() = LnkTLI17;
static object  LnkTLI16() ;
static object  (*LnkLI16)() = LnkTLI16;
static object  LnkTLI15() ;
static object  (*LnkLI15)() = LnkTLI15;
static object  LnkTLI14() ;
static object  (*LnkLI14)() = LnkTLI14;
static object  LnkTLI13() ;
static object  (*LnkLI13)() = LnkTLI13;
static  LnkT12() ;
static  (*Lnk12)() = LnkT12;
static object  LnkTLI11() ;
static object  (*LnkLI11)() = LnkTLI11;
static object  LnkTLI10() ;
static object  (*LnkLI10)() = LnkTLI10;
static object  LnkTLI9() ;
static object  (*LnkLI9)() = LnkTLI9;

==> gcl-2.0.tgz: gcl-2.0/lsp/numlib.h <==

static L15();
static L16();
static L17();
static L18();
static object LI1();
#define VMB1 register object *base=vs_top;
#define VMS1  register object *sup=vs_top+4;vs_top=sup;
#define VMV1 vs_reserve(4);
#define VMR1(VMT1) vs_top=base ; return(VMT1);
static object LI2();
#define VMB2 register object *base=vs_top; object  V15 ,V14 ,V13 ,V12 ,V11 ,V10;
#define VMS2  register object *sup=vs_top+2;vs_top=sup;
#define VMV2 vs_reserve(2);
#define VMR2(VMT2) vs_top=base ; return(VMT2);
static object LI3();
#define VMB3 register object *base=vs_top;
#define VMS3  register object *sup=vs_top+3;vs_top=sup;
#define VMV3 vs_reserve(3);
#define VMR3(VMT3) vs_top=base ; return(VMT3);
static object LI4();
#define VMB4 register object *base=vs_top;
#define VMS4  register object *sup=vs_top+2;vs_top=sup;
#define VMV4 vs_reserve(2);
#define VMR4(VMT4) vs_top=base ; return(VMT4);
static object LI5();
#define VMB5 register object *base=vs_top;
#define VMS5  register object *sup=vs_top+1;vs_top=sup;
#define VMV5 vs_reserve(1);
#define VMR5(VMT5) vs_top=base ; return(VMT5);
static object LI6();
#define VMB6 register object *base=vs_top; object  V37 ,V36 ,V35 ,V34 ,V33 ,V32;
#define VMS6  register object *sup=vs_top+2;vs_top=sup;
#define VMV6 vs_reserve(2);
#define VMR6(VMT6) vs_top=base ; return(VMT6);
static object LI7();
#define VMB7 register object *base=vs_top; object  V48 ,V47 ,V46 ,V45 ,V44 ,V43;
#define VMS7  register object *sup=vs_top+2;vs_top=sup;
#define VMV7 vs_reserve(2);
#define VMR7(VMT7) vs_top=base ; return(VMT7);
static object LI8();
#define VMB8 register object *base=vs_top; object  V54 ,V53;
#define VMS8  register object *sup=vs_top+2;vs_top=sup;
#define VMV8 vs_reserve(2);
#define VMR8(VMT8) vs_top=base ; return(VMT8);
static object LI9();
#define VMB9 register object *base=vs_top; object  V59 ,V58;
#define VMS9  register object *sup=vs_top+2;vs_top=sup;
#define VMV9 vs_reserve(2);
#define VMR9(VMT9) vs_top=base ; return(VMT9);
static object LI10();
#define VMB10 register object *base=vs_top;
#define VMS10  register object *sup=vs_top+2;vs_top=sup;
#define VMV10 vs_reserve(2);
#define VMR10(VMT10) vs_top=base ; return(VMT10);
static object LI11();
#define VMB11 register object *base=vs_top; object  V67 ,V66;
#define VMS11  register object *sup=vs_top+2;vs_top=sup;
#define VMV11 vs_reserve(2);
#define VMR11(VMT11) vs_top=base ; return(VMT11);
static object LI12();
#define VMB12 register object *base=vs_top; object  V73 ,V72 ,V71;
#define VMS12  register object *sup=vs_top+4;vs_top=sup;
#define VMV12 vs_reserve(4);
#define VMR12(VMT12) vs_top=base ; return(VMT12);
static object LI13();
#define VMB13 register object *base=vs_top; object  V77;
#define VMS13  register object *sup=vs_top+4;vs_top=sup;
#define VMV13 vs_reserve(4);
#define VMR13(VMT13) vs_top=base ; return(VMT13);
static object LI14();
#define VMB14 register object *base=vs_top; object  V90 ,V89 ,V88 ,V86 ,V85;
#define VMS14  register object *sup=vs_top+1;vs_top=sup;
#define VMV14 vs_reserve(1);
#define VMR14(VMT14) vs_top=base ; return(VMT14);
#define VC15
#define VC16
#define VC17
#define VC18
static object LI19();
#define VMB19 register object *base=vs_top;
#define VMS19  register object *sup=vs_top+3;vs_top=sup;
#define VMV19 vs_reserve(3);
#define VMR19(VMT19) vs_top=base ; return(VMT19);
static object LI20();
#define VMB20 register object *base=vs_top;
#define VMS20  register object *sup=vs_top+3;vs_top=sup;
#define VMV20 vs_reserve(3);
#define VMR20(VMT20) vs_top=base ; return(VMT20);
static object LI21();
#define VMB21 register object *base=vs_top;
#define VMS21  register object *sup=vs_top+3;vs_top=sup;
#define VMV21 vs_reserve(3);
#define VMR21(VMT21) vs_top=base ; return(VMT21);
static object LI22();
#define VMB22 register object *base=vs_top;
#define VMS22  register object *sup=vs_top+3;vs_top=sup;
#define VMV22 vs_reserve(3);
#define VMR22(VMT22) vs_top=base ; return(VMT22);
static object LI23();
#define VMB23 register object *base=vs_top;
#define VMS23  register object *sup=vs_top+3;vs_top=sup;
#define VMV23 vs_reserve(3);
#define VMR23(VMT23) vs_top=base ; return(VMT23);
static object LI24();
#define VMB24 register object *base=vs_top;
#define VMS24  register object *sup=vs_top+3;vs_top=sup;
#define VMV24 vs_reserve(3);
#define VMR24(VMT24) vs_top=base ; return(VMT24);
static object LI25();
#define VMB25 register object *base=vs_top;
#define VMS25  register object *sup=vs_top+2;vs_top=sup;
#define VMV25 vs_reserve(2);
#define VMR25(VMT25) vs_top=base ; return(VMT25);
static object LI26();
#define VMB26 register object *base=vs_top;
#define VMS26  register object *sup=vs_top+4;vs_top=sup;
#define VMV26 vs_reserve(4);
#define VMR26(VMT26) vs_top=base ; return(VMT26);
static object LI27();
#define VMB27
#define VMS27
#define VMV27
#define VMR27(VMT27) return(VMT27);
static object LI28();
#define VMB28
#define VMS28
#define VMV28
#define VMR28(VMT28) return(VMT28);
static object LI29();
#define VMB29
#define VMS29
#define VMV29
#define VMR29(VMT29) return(VMT29);
static object LI30();
#define VMB30 register object *base=vs_top; object  V166 ,V165 ,V164 ,V163;
#define VMS30  register object *sup=vs_top+2;vs_top=sup;
#define VMV30 vs_reserve(2);
#define VMR30(VMT30) vs_top=base ; return(VMT30);
static object LI31();
#define VMB31 register object *base=vs_top;
#define VMS31  register object *sup=vs_top+2;vs_top=sup;
#define VMV31 vs_reserve(2);
#define VMR31(VMT31) vs_top=base ; return(VMT31);
static object LI32();
#define VMB32 register object *base=vs_top;
#define VMS32  register object *sup=vs_top+2;vs_top=sup;
#define VMV32 vs_reserve(2);
#define VMR32(VMT32) vs_top=base ; return(VMT32);
static object LI33();
#define VMB33 register object *base=vs_top; object  V185 ,V184;
#define VMS33  register object *sup=vs_top+6;vs_top=sup;
#define VMV33 vs_reserve(6);
#define VMR33(VMT33) vs_top=base ; return(VMT33);
static object LI34();
#define VMB34 register object *base=vs_top; object  V194 ,V193;
#define VMS34  register object *sup=vs_top+2;vs_top=sup;
#define VMV34 vs_reserve(2);
#define VMR34(VMT34) vs_top=base ; return(VMT34);
#define VM34 2
#define VM33 6
#define VM32 2
#define VM31 2
#define VM30 2
#define VM29 0
#define VM28 0
#define VM27 0
#define VM26 4
#define VM25 2
#define VM24 3
#define VM23 3
#define VM22 3
#define VM21 3
#define VM20 3
#define VM19 3
#define VM18 5
#define VM17 5
#define VM16 5
#define VM15 5
#define VM14 1
#define VM13 4
#define VM12 4
#define VM11 2
#define VM10 2
#define VM9 2
#define VM8 2
#define VM7 2
#define VM6 2
#define VM5 1
#define VM4 2
#define VM3 3
#define VM2 2
#define VM1 4
static char * VVi[44]={
#define Cdata VV[43]
(char *)(LI1),
(char *)(LI2),
(char *)(LI3),
(char *)(LI4),
(char *)(LI5),
(char *)(LI6),
(char *)(LI7),
(char *)(LI8),
(char *)(LI9),
(char *)(LI10),
(char *)(LI11),
(char *)(LI12),
(char *)(LI13),
(char *)(LI14),
(char *)(L15),
(char *)(L16),
(char *)(L17),
(char *)(L18),
(char *)(LI19),
(char *)(LI20),
(char *)(LI21),
(char *)(LI22),
(char *)(LI23),
(char *)(LI24),
(char *)(LI25),
(char *)(LI26),
(char *)(LI27),
(char *)(LI28),
(char *)(LI29),
(char *)(LI30),
(char *)(LI31),
(char *)(LI32),
(char *)(LI33),
(char *)(LI34)
};
#define VV ((object *)VVi)
static object  LnkTLI42() ;
static object  (*LnkLI42)() = LnkTLI42;
static object  LnkTLI41() ;
static object  (*LnkLI41)() = LnkTLI41;
static object  LnkTLI40() ;
static object  (*LnkLI40)() = LnkTLI40;
static object  LnkTLI39() ;
static object  (*LnkLI39)() = LnkTLI39;
static object  LnkTLI38() ;
static object  (*LnkLI38)() = LnkTLI38;
static object  LnkTLI37() ;
static object  (*LnkLI37)() = LnkTLI37;
static  LnkT36() ;
static  (*Lnk36)() = LnkT36;
static  LnkT35() ;
static  (*Lnk35)() = LnkT35;
static  LnkT34() ;
static  (*Lnk34)() = LnkT34;
static  LnkT33() ;
static  (*Lnk33)() = LnkT33;
static  LnkT32() ;
static  (*Lnk32)() = LnkT32;
static  LnkT31() ;
static  (*Lnk31)() = LnkT31;
static  LnkT30() ;
static  (*Lnk30)() = LnkT30;
static  LnkT29() ;
static  (*Lnk29)() = LnkT29;
static object  LnkTLI28() ;
static object  (*LnkLI28)() = LnkTLI28;
static  LnkT27() ;
static  (*Lnk27)() = LnkT27;
static  LnkT26() ;
static  (*Lnk26)() = LnkT26;
static  LnkT25() ;
static  (*Lnk25)() = LnkT25;
static object  LnkTLI24() ;
static object  (*LnkLI24)() = LnkTLI24;
static object  LnkTLI23() ;
static object  (*LnkLI23)() = LnkTLI23;
static  LnkT22() ;
static  (*Lnk22)() = LnkT22;
static  LnkT21() ;
static  (*Lnk21)() = LnkT21;
static  LnkT20() ;
static  (*Lnk20)() = LnkT20;
static object  LnkTLI19() ;
static object  (*LnkLI19)() = LnkTLI19;
static  LnkT18() ;
static  (*Lnk18)() = LnkT18;
static  LnkT17() ;
static  (*Lnk17)() = LnkT17;
static  LnkT16() ;
static  (*Lnk16)() = LnkT16;
static  LnkT15() ;
static  (*Lnk15)() = LnkT15;
static  LnkT14() ;
static  (*Lnk14)() = LnkT14;
static  LnkT13() ;
static  (*Lnk13)() = LnkT13;
static  LnkT12() ;
static  (*Lnk12)() = LnkT12;
static  LnkT11() ;
static  (*Lnk11)() = LnkT11;
static  LnkT10() ;
static  (*Lnk10)() = LnkT10;
static  LnkT9() ;
static  (*Lnk9)() = LnkT9;
